

;;; Info
;; setup up info directories to conform to debian standards.

(setq Info-directory-list
      '("/usr/info/" "/usr/share/info" "/usr/local/info"
        "/usr/share/xemacs21/packages/info"
        "/usr/share/xemacs21/mule-packages/info"
        "/usr/share/xemacs21/site-packages/info"))

(setq Info-additional-search-directory-list
      '("/usr/share/info/xemacs-21.4.6"))

(loop for entry in load-history
  if (string-match "^/home/dres/.*xemacs21/xemacs\\(21\\)?-\\([.0-9]+/\\)"
                   (car entry))
  do (setf (car entry)
           (replace-match "/usr/lib/xemacs-\\2" t nil (car entry))))


;; from bugreport #76139
(setq TeX-lisp-directory "/usr/share/xemacs21/packages/etc/auctex/")

;;; PSGML section
(setq-default sgml-local-catalogs '("/usr/lib/sgml/catalog"))

(setq sgml-ecat-files '("ECAT" "~/sgml/ECAT" "/usr/lib/sgml/ECAT"
                         "/usr/local/lib/sgml/ECAT" ))

(or (assoc "\\.html$" auto-mode-alist)
    (setq auto-mode-alist (cons '("\\.html$" . html-mode)
				auto-mode-alist)))
(or (assoc "\\.shtml$" auto-mode-alist)
    (setq auto-mode-alist (cons '("\\.shtml$" . html-mode)
				auto-mode-alist)))

(or (assoc "\\.htm$" auto-mode-alist)
    (setq auto-mode-alist (cons '("\\.htm$" . html-mode)
				auto-mode-alist)))
(or (assoc "\\.shtm$" auto-mode-alist)
    (setq auto-mode-alist (cons '("\\.shtm$" . html-mode)
				auto-mode-alist)))

;;(while (rassoc 'html-mode  auto-mode-alist)
;;  (setcdr (rassoc 'html-mode  auto-mode-alist) 'sgml-html-mode))
;; (defalias 'html-mode 'sgml-html-mode)

(setq auto-mode-alist (append '(("\\.xml$" . xml-mode)) auto-mode-alist))

(setq-default sgml-indent-data t)
(setq
 sgml-always-quote-attributes t
 sgml-auto-insert-required-elements t
 sgml-auto-activate-dtd t
 sgml-data-directory "/usr/lib/sgml/declaration/"
 sgml-indent-data t
 sgml-indent-step             2
 sgml-minimize-attributes     nil
 sgml-omittag                 nil
 sgml-shortag                 nil
 sgml-custom-markup
 '(("Version1" "<![%Version1[\r]]>")
   ("New page"  "<?NewPage>"))
 sgml-xml-declaration "/usr/lib/sgml/declaration/xml.dcl"
 sgml-display-char-list-filename "/usr/lib/sgml/charsets/iso88591.map"
 sgml-live-element-indicator t
 sgml-public-map '("%S"  "/usr/lib/sgml/%S" "/usr/lib/sgml/%o/%c/%d"
		   "/usr/local/lib/sgml/%o/%c/%d")
 sgml-set-face (eq 'x  window-system)
 sgml-system-path '("/usr/lib/sgml" "/usr/lib/sgml/cdtd" "/usr/local/lib/sgml")
 sgml-tag-region-if-active t
 sgml-validate-command "nsgmls -e -g -s -u %s %s "
 )
(if (eq 'x  window-system)
    (setq sgml-markup-faces
	  '((start-tag . font-lock-keyword-face)
	    (end-tag . font-lock-keyword-face)
	    (ignored . font-lock-string-face)
	    (ms-start . font-lock-type-face)
	    (ms-end . font-lock-type-face)
	    (shortref . bold)
	    (entity . font-lock-reference-face)
	    (comment . font-lock-comment-face)
	    (pi . font-lock-variable-name-face)
	    (sgml . font-lock-function-name-face)
	    (doctype . font-lock-doc-string-face)))
  )

;;; END PSGML section

(setq news-path "/var/spool/news")

(custom-set-variables ;;'(nnmail-spool-file "/var/spool/mail/$user")
                      '(gnuserv-program 
                          (concat exec-directory "/gnuserv")))

(when (functionp 'make-coding-system)
    (make-coding-system 'us-ascii nil))

(setq Manual-snip-subchapter nil)

(if (file-executable-p "/bin/chown")
    (setq dired-chown-program "/bin/chown")
  (setq dired-chown-program "/usr/bin/chown"))

(global-set-key [iso-left-tab] [(shift tab)])
(global-set-key [(control iso-left-tab)] [(control shift tab)])

(defun dir-and-all-good-subs (this-directory)
  "Returns list of argument and all subdirectories of argument not
starting with a '.'"
  (if (file-exists-p this-directory)
      (append (list (expand-file-name this-directory))
              (mapcar '(lambda (dir-string)
                         (concat dir-string "/")) 
                      (directory-files 
                       (expand-file-name this-directory) 
                       t "^[^\\.]" nil 1)))
    nil))

;; make delete work correctly on console
(setq delete-key-deletes-forward t)

(setq load-path
      (let* ((point
              (string-match "[0-9]*\.[0-9]*.*XEmacs.*"
                            emacs-version))
             (xemacs-maj-version
              (substring emacs-version point (+ point 2)))
             (xemacs-version
              (substring emacs-version point (+ point 5))))
        (append
         (dir-and-all-good-subs
          (expand-file-name "~/.xemacs/xemacs-packages"))
         (dir-and-all-good-subs
          (expand-file-name "~/.xemacs/packages"))
         '("/etc/xemacs21")
         '("/etc/emacs")
         '("/usr/local/share/emacs/xemacs-21.4.6/site-lisp")
         '("/usr/local/share/emacs/site-lisp")
         `(,@(dir-and-all-good-subs "/usr/local/lib/xemacs/site-lisp")
             ,@(dir-and-all-good-subs
                (concat "/usr/share/xemacs/site-lisp-" xemacs-maj-version "/"))
             ,@(dir-and-all-good-subs "/usr/share/xemacs/site-lisp/")
             ,@(dir-and-all-good-subs
                (concat "/usr/share/xemacs" xemacs-maj-version "/site-lisp/"))
             )
         load-path
         ;;,@(dir-and-all-good-subs "/usr/share/emacs/site-lisp/")
         ;;,@(dir-and-all-good-subs
         ;; (concat "/usr/share/xemacs-" xemacs-version "/lisp/"))
         '("/usr/share/emacs/site-lisp"))))

;; make sure all the autoloads are up to date
(packages-reload-autoloads)

;; should now load from one of the /etc dirs since they are first in
;; the path now.
(load "site-start")

;;; end 00debian.el

;; Local Variables:
;; mode: emacs-lisp
;; End:
